@@ -17,14 +17,14 @@ use File::Find::Rule::VCS;
 use File::Slurp ();
 use File::Spec;
 use Log::Any qw/$log/;
-use Module::Build::ModuleInfo;
+use Module::Metadata;
 use Pod::Elemental;
 use Pod::Elemental::Transformer::Pod5;
 use Pod::Weaver;
 use PPI::Document;
 use Try::Tiny;
 
-our $VERSION = '0.99_03';
+our $VERSION = '0.99_04';
 
 sub FAIL()              { 0; }
 sub SUCCESS_UNCHANGED() { 1; }
@@ -101,10 +101,10 @@ sub weave_file
         filename     => $file,
         );
 
-    $module_info = Module::Build::ModuleInfo->new_from_file( $file );
-    if( $module_info and defined( $module_info->{ version } ) )
+    $module_info = Module::Metadata->new_from_file( $file );
+    if( $module_info and defined( $module_info->version() ) )
     {
-        $weave_args{ version } = $module_info->{ version };
+        $weave_args{ version } = $module_info->version();
     }
     elsif( defined( $input{ dist_version } ) )
     {
@@ -436,7 +436,7 @@ App::podweaver - Run Pod::Weaver on the files within a distribution.
 
 =head1 VERSION
 
-version 0.99_03
+version 0.99_04
 
 =head1 SYNOPSIS
 
@@ -537,7 +537,7 @@ the original.
 =item B<< dist_version => >> I<$version>
 
 If no C<$VERSION> can be parsed from the file by
-L<Module::Build::ModuleInfo>, the version supplied in
+L<Module::Metadata>, the version supplied in
 C<dist_version> will be used as a fallback.
 
 =back
